@@ -29,7 +29,7 @@
 #include "private/queuehelper_p.h"
 
 
-#include <QtNetwork/QNetworkRequest>
+#include <QNetworkRequest>
 #include <QNetworkReply>
 
 using namespace KGAPI2;
@@ -79,7 +79,7 @@ void CalendarModifyJob::start()
     QStringList headers;
     const auto rawHeaderList = request.rawHeaderList();
     headers.reserve(rawHeaderList.size());
-    Q_FOREACH(const QByteArray &str, rawHeaderList) {
+    for (const QByteArray &str : qAsConst(rawHeaderList)) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
     qCDebug(KGAPIRaw) << headers;
