@@ -26,9 +26,9 @@
 #include "contactsservice.h"
 #include "private/queuehelper_p.h"
 
-#include <QtNetwork/QNetworkRequest>
-#include <QtNetwork/QNetworkReply>
-#include <QtGui/QImage>
+#include <QNetworkRequest>
+#include <QNetworkReply>
+#include <QImage>
 
 Q_DECLARE_METATYPE(KGAPI2::ContactPtr)
 
